diff --git a/homeassistant/package_constraints.txt b/homeassistant/package_constraints.txt
index f6b596b26abf45d9c2e7b3b45f79eccf0cde2613..8a5ae2dde364225901fe3958e2067c7bd803f6ab 100644
--- a/homeassistant/package_constraints.txt
+++ b/homeassistant/package_constraints.txt
@@ -19,7 +19,7 @@ bluetooth-data-tools==1.19.0
 cached_ipaddress==0.3.0
 certifi>=2021.5.30
 ciso8601==2.3.0
-cryptography==41.0.7
+cryptography==42.0.1
 dbus-fast==2.21.1
 fnv-hash-fast==0.5.0
 ha-av==10.1.1
@@ -44,7 +44,7 @@ pip>=21.3.1
 psutil-home-assistant==0.0.1
 PyJWT==2.8.0
 PyNaCl==1.5.0
-pyOpenSSL==23.2.0
+pyOpenSSL==24.0.0
 pyserial==3.5
 python-slugify==8.0.1
 PyTurboJPEG==1.7.1
@@ -145,9 +145,9 @@ iso4217!=1.10.20220401
 # We need at least >=2.1.0 (tensorflow integration -> pycocotools)
 matplotlib==3.6.1
 
-# pyOpenSSL 23.1.0 or later required to avoid import errors when
-# cryptography 40.0.1 is installed with botocore
-pyOpenSSL>=23.1.0
+# pyOpenSSL 24.0.0 or later required to avoid import errors when
+# cryptography 42.0.0 is installed with botocore
+pyOpenSSL>=24.0.0
 
 # protobuf must be in package constraints for the wheel
 # builder to build binary wheels
diff --git a/pyproject.toml b/pyproject.toml
index 99027f29b8d29a5222d925f334235ef2df244bbe..6ed57860ee75e21281e481f48a7feaf3095464d1 100644
--- a/pyproject.toml
+++ b/pyproject.toml
@@ -43,9 +43,9 @@ dependencies    = [
     "lru-dict==1.3.0",
     "PyJWT==2.8.0",
     # PyJWT has loose dependency. We want the latest one.
-    "cryptography==41.0.7",
+    "cryptography==42.0.1",
     # pyOpenSSL 23.2.0 is required to work with cryptography 41+
-    "pyOpenSSL==23.2.0",
+    "pyOpenSSL==24.0.0",
     "orjson==3.9.12",
     "packaging>=23.1",
     "pip>=21.3.1",
diff --git a/requirements.txt b/requirements.txt
index cd5a84a506df34e8bbac975e0b15f8cb109da5d7..75fd75f617781ca248627ea98820a298a2c489d3 100644
--- a/requirements.txt
+++ b/requirements.txt
@@ -20,8 +20,8 @@ ifaddr==0.2.0
 Jinja2==3.1.3
 lru-dict==1.3.0
 PyJWT==2.8.0
-cryptography==41.0.7
-pyOpenSSL==23.2.0
+cryptography==42.0.1
+pyOpenSSL==24.0.0
 orjson==3.9.12
 packaging>=23.1
 pip>=21.3.1
diff --git a/script/gen_requirements_all.py b/script/gen_requirements_all.py
index ee0eee21e591633d14fcabc344e07823564a54db..64d897b7ee7993ddf4826330a26d0e1a240dad2c 100755
--- a/script/gen_requirements_all.py
+++ b/script/gen_requirements_all.py
@@ -138,9 +138,9 @@ iso4217!=1.10.20220401
 # We need at least >=2.1.0 (tensorflow integration -> pycocotools)
 matplotlib==3.6.1
 
-# pyOpenSSL 23.1.0 or later required to avoid import errors when
-# cryptography 40.0.1 is installed with botocore
-pyOpenSSL>=23.1.0
+# pyOpenSSL 24.0.0 or later required to avoid import errors when
+# cryptography 42.0.0 is installed with botocore
+pyOpenSSL>=24.0.0
 
 # protobuf must be in package constraints for the wheel
 # builder to build binary wheels